@@ -29,7 +29,7 @@ getME(fm4 <- lmer(Reaction ~ Days + (1|Subject) + (0+Days|Subject), sleepstudy),
       "theta")
 
 ## internal consistency check ensuring that all allowed 'name's work (and are not empty):
-(nmME <- eval(formals(getME)$name))
+(nmME <- eval(formals(lme4:::getME.merMod)$name))
 chkMEs <- function(fm, nms) {
     stopifnot(is.character(nms))
     str(parts <- sapply(nms, getME, object = fm, simplify=FALSE))
